@@ -6,7 +6,8 @@ from glob import glob
 import os
 from pathlib import Path
 from lxml import etree
-
+import sys
+# local
 from py4ami.util import Util
 from py4ami.ami_config import AmiConfig
 from py4ami.wikimedia import WikidataSparql as WS
@@ -20,6 +21,19 @@ skip_config_test = True
 def tests():
     AmiConfig.test_dicts()
 
+class AmiAnyTest(unittest.TestCase):
+
+    def setUp(self) -> None:
+        if len(sys.argv) == 0:
+            sys.argv = ["ami"]
+        self.argv_copy = list(sys.argv)
+
+    def tearDown(self) -> None:
+        # print(f"argv_copy {self.argv_copy}")
+        # print(f"argv {sys.argv}")
+        self.argv =  list(self.argv_copy)
+
+
 class UtilTests:
     def test_dict_read():
         file = "section_templates.json"
