@@ -980,6 +980,17 @@ LTPage
         except SystemExit:
             pass
 
+    def test_subcommands(self):
+        # args = ['PDF', '--help']
+        # pyamix = PyAMI()
+        # pyamix.run_command(args)
+        #
+        inpath = Path(Resources.PDFS_DIR, "1758-2946-3-44.pdf")
+        outdir = Path(Resources.TEMP_DIR, "pdf", "1758-2946-3-44")
+        args = ['PDF', '--inpath', str(inpath), '--outdir', str(outdir), '--pages', '_2', '4', '6_8', '11_']
+        pyamix = PyAMI()
+        pyamix.run_command(args)
+
 
     # =====================================================================================================
     # =====================================================================================================
